@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.2007';
+our $VERSION = '0.2008';
 
 use Algorithm::Combinatorics qw(variations_with_repetition);
 use MIDI::Util qw(dura_size);
@@ -468,7 +468,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.2007
+version 0.2008
 
 =head1 SYNOPSIS
 
@@ -490,11 +490,11 @@ version 0.2007
 
  $d->metronome54;  # 5/4 time for the number of bars
 
- $d->set_time_sig('4/4');
-
  $d->rest($d->whole);
 
- $d->metronome44;  # 4/4 time for the number of bars
+ $d->set_time_sig('4/4');
+
+ $d->metronome44(3);  # 4/4 time for 3 bars
 
  $d->flam($d->quarter, $d->snare);
  $d->crescendo_roll([50, 127, 1], $d->eighth, $d->thirtysecond);
@@ -505,7 +505,10 @@ version 0.2007
  $d->note($d->quarter, $d->open_hh, $_ % 2 ? $d->kick : $d->snare)
     for 1 .. $d->beats * $d->bars;
 
- $d->combinatorial( $d->snare, { patterns => [qw(0101 1001)] } );
+ $d->combinatorial( $d->snare, {
+    repeat   => 2,
+    patterns => [qw(0101 1001)],
+ });
 
  # Play parts simultaneously
  $d->sync( \&snare, \&kick, \&hhat );
@@ -662,7 +665,7 @@ Return a new C<MIDI::Drummer::Tiny> object.
  $d->note( $d->quarter, $d->closed_hh, $d->kick );
  $d->note( 'qn', 'n42', 'n35' ); # Same thing
 
-Add a note to the score.
+Add notes to the score.
 
 This method takes the same arguments as L<MIDI::Simple/"Parameters for n/r/noop">.
 
